ReportLab Preppy Test Suite 003

# Preppy Test 003 - The "If" Tag

This test sets a test variable and uses the Preppy if, else and elif statements to make tests on it.

## Expected Output

You should see three sets of results.
The first line of each result will tell you the status of the test variable, and if all is well there should be a second line in italics below it.

The test variable is '10'.
You should see this line if the test variable is equal to '10'
The test variable is now '20'.
You should see this line if the test variable is not equal to '10'
The test variable is '20'
You should see this line if the test variable is equal to '20'